==> rendition-14.9.0.tgz: package/dist_esm5/components/Badge/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { getLegibleTextColor } from '../../utils';
import Txt from '../Txt';
var shades = [
    '#C7FFFF',
    '#BAECC2',
    '#FFD4F1',
    '#F1CDE3',
    '#D7E4FE',
    '#FFD5D2',
    '#CAE1AC',
    '#D6D3FA',
    '#C3C7CA',
    '#FFDA93',
    '#E1EEE5',
    '#DBE0E3',
    '#FEEC63',
    '#FBE6F4',
    '#FFECAE',
    '#F1CDFF',
    '#C3EFFF',
    '#F3E8FD',
    '#E0FEB4',
    '#FDE8E7',
    '#CAFECD',
    '#D7E46C',
    '#F7D8BA',
];
var BaseBadge = styled(Txt.span)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tfont-family: ", ";\n\tdisplay: inline-block;\n\tborder-radius: 1em;\n\tline-height: 1;\n"], ["\n\tfont-family: ", ";\n\tdisplay: inline-block;\n\tborder-radius: 1em;\n\tline-height: 1;\n"])), function (props) { return props.theme.titleFont; });
var Badge = function (_a) {
    var children = _a.children, className = _a.className, shade = _a.shade, otherProps = __rest(_a, ["children", "className", "shade"]);
    if (typeof children !== 'string') {
        throw new Error("The child element of the Badge component must be a string, received: " + typeof children);
    }
    var shadeHex = shades[(shade || 0) % shades.length];
    return (React.createElement(BaseBadge, __assign({ className: className, py: 1, px: "12px", fontSize: 0, bg: shadeHex }, otherProps, { color: getLegibleTextColor(shadeHex) }), children));
};
export default asRendition(Badge);
var templateObject_1;

==> rendition-18.4.1.tgz: package/dist_esm5/components/Badge/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { getLegibleTextColor } from '../../utils';
import Txt from '../Txt';
var shades = [
    '#C7FFFF',
    '#BAECC2',
    '#FFD4F1',
    '#F1CDE3',
    '#D7E4FE',
    '#FFD5D2',
    '#CAE1AC',
    '#D6D3FA',
    '#C3C7CA',
    '#FFDA93',
    '#E1EEE5',
    '#DBE0E3',
    '#FEEC63',
    '#FBE6F4',
    '#FFECAE',
    '#F1CDFF',
    '#C3EFFF',
    '#F3E8FD',
    '#E0FEB4',
    '#FDE8E7',
    '#CAFECD',
    '#D7E46C',
    '#F7D8BA',
];
var BaseBadge = styled(Txt.span)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tdisplay: inline-block;\n\tborder-radius: 1em;\n\tline-height: 1;\n"], ["\n\tdisplay: inline-block;\n\tborder-radius: 1em;\n\tline-height: 1;\n"])));
var Badge = function (_a) {
    var children = _a.children, className = _a.className, shade = _a.shade, otherProps = __rest(_a, ["children", "className", "shade"]);
    if (typeof children !== 'string') {
        throw new Error("The child element of the Badge component must be a string, received: " + typeof children);
    }
    var shadeHex = shades[(shade || 0) % shades.length];
    return (React.createElement(BaseBadge, __assign({ className: className, py: 1, px: "12px", fontSize: 1, bg: shadeHex }, otherProps, { color: getLegibleTextColor(shadeHex) }), children));
};
export default asRendition(Badge);
var templateObject_1;
